package com.gree.mall.contest.controller.pc.coupon;


import com.baomidou.mybatisplus.core.metadata.IPage;
import com.gree.mall.contest.bean.coupon.*;
import com.gree.mall.contest.exception.RemoteServiceException;
import com.gree.mall.contest.helper.ResponseHelper;
import com.gree.mall.contest.logic.coupon.CouponLogic;
import io.swagger.v3.oas.annotations.Parameter;
import io.swagger.v3.oas.annotations.media.Schema;
import io.swagger.v3.oas.annotations.tags.Tag;
import lombok.extern.slf4j.Slf4j;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.io.IOException;
import java.text.ParseException;
import java.util.Date;

@Slf4j
@RestController
@Tag(name = "优惠券管理", description ="优惠券管理" )
@RequestMapping(value = "/pc/coupon", produces = "application/json; charset=utf-8")
public class CouponController {

    @Resource
    CouponLogic couponLogic;

    @GetMapping("/list/page")
     @Schema(description = "优惠券列表")
    public ResponseHelper<IPage<CouponPageBean>> page(
            @Parameter(description = "券名称") @RequestParam(required = false) String couponName,
            @Parameter(description = "券类型") @RequestParam(required = false) String couponType,
            @Parameter(description = "券标志") @RequestParam(required = false) String flag,
            @Parameter(description = "页号",required = true) @RequestParam Integer pageNum,
            @Parameter(description = "页大小",required = true) @RequestParam Integer pageSize,
            HttpServletRequest request
    ) throws RemoteServiceException {
        IPage<CouponPageBean> page = couponLogic.page(couponName, couponType, flag, pageNum, pageSize,request);
        return ResponseHelper.success(page);
    }

    @GetMapping("/detail")
     @Schema(description = "券详情")
    public ResponseHelper<CouponDetailBean> detail(
            @Parameter(description = "id",required = true) @RequestParam String couponId
    ) throws RemoteServiceException {
        CouponDetailBean detail = couponLogic.detail(couponId);
        return ResponseHelper.success(detail);
    }

    @PostMapping("/add")
     @Schema(description = "新增券")
    public ResponseHelper add(
            HttpServletRequest request,
            @Parameter(description = "object",required = true) @RequestBody CouponBean couponBean)
            throws RemoteServiceException {
        couponLogic.add(request, couponBean);
        return ResponseHelper.success();
    }

    @PostMapping("/update")
     @Schema(description = "修改券")
    public ResponseHelper update(
            HttpServletRequest request,
            @Parameter(description = "object",required = true) @RequestBody CouponBean couponBean)
            throws RemoteServiceException {
        couponLogic.update(request, couponBean);
        return ResponseHelper.success();
    }


    @PostMapping("/reissue")
     @Schema(description = "补发业务员券")
    public ResponseHelper reissueCoupon(
            HttpServletRequest request,
            @Parameter(description = "object",required = true) @RequestBody ReissueCouponBean reissueCouponBean)
            throws RemoteServiceException {
        couponLogic.reissueCoupon(request, reissueCouponBean);
        return ResponseHelper.success();
    }

    @PostMapping("/change/flag")
     @Schema(description = "券标志")
    public ResponseHelper change(
            @Parameter(description = "券id",required = true) @RequestParam String couponId,
            @Parameter(description = "开始时间") @RequestParam(required = false) String startDate,
            @Parameter(description = "结束时间") @RequestParam(required = false) String endDate,
            @Parameter(description = "券标志:START=进行中 CANCEL=取消",required = true) @RequestParam String flag
    ) throws RemoteServiceException {
        couponLogic.updateFlag(couponId, startDate, endDate, flag);
        return ResponseHelper.success();
    }

    @GetMapping("/data")
     @Schema(description = "券数据")
    public ResponseHelper<CouponBean> data(
            @Parameter(description = "id",required = true) @RequestParam String couponId
    ) throws RemoteServiceException {
        CouponDataBean data = couponLogic.data(couponId);
        return ResponseHelper.success(data);
    }

    @GetMapping("/userCouponDetail/query")
     @Schema(description = "用户领取优惠券明细")
    public ResponseHelper<IPage<UserCouponBean>> receiveCouponDetail(
            @Parameter(description = "我的优惠券id",required = true) @RequestParam String userCouponId,
            @Parameter(description = "页号",required = true) @RequestParam Integer pageNo,
            @Parameter(description = "页大小",required = true) @RequestParam Integer pageSize
            )throws RemoteServiceException{
        return ResponseHelper.success(couponLogic.receiveCouponDetail(userCouponId,pageNo,pageSize));
    }

    @GetMapping("/user/page")
     @Schema(description = "获取领取优惠券用户列表")
    public ResponseHelper<CouponBean> user(
            HttpServletRequest request,
            @Parameter(description = "手机号",required = false) @RequestParam(required = false) String tel,
            @Parameter(description = "注册时间",required = false) @RequestParam(required = false) Date registerTime,
            @Parameter(description = "keyword",required = false) @RequestParam(required = false)String keyword,
            @Parameter(description = "角色 GENERAL=普通用户 SERVICE=业务员",required = false) @RequestParam(required = false)String type,
            @Parameter(description = "页号",required = true) @RequestParam Integer pageNo,
            @Parameter(description = "页大小",required = true) @RequestParam Integer pageSize
    ) throws RemoteServiceException {
        return ResponseHelper.success(couponLogic.userList(request, tel,registerTime,keyword,type,pageNo,pageSize));
    }


    @GetMapping("/list/spec/select")
     @Schema(description = "优惠券选择活动商品列表")
    public ResponseHelper pageSpecGoods(
            HttpServletRequest request,
            @Parameter(description = "商品名称") @RequestParam(required = false) String keyword,
            @Parameter(description = "商品分类id") @RequestParam(required = false) String categoryId,
            @Parameter(description = "页号",required = true) @RequestParam Integer pageNum,
            @Parameter(description = "页大小",required = true) @RequestParam Integer pageSize
    ) throws Exception {
        return ResponseHelper.success(couponLogic.goodsSpecList(request, categoryId,keyword,pageNum, pageSize));
    }


    @GetMapping("/list/export")
     @Schema(description = "优惠券导出")
    public void export(HttpServletRequest request, HttpServletResponse response,
                                                        @Parameter(description = "券名称") @RequestParam(required = false) String couponName,
                                                        @Parameter(description = "券类型") @RequestParam(required = false) String couponType,
                                                        @Parameter(description = "券标志") @RequestParam(required = false) String flag
    ) throws Exception {
        couponLogic.export(request,response,couponName, couponType, flag);
    }




}
